@@ -69,6 +69,7 @@ public:
 
   QString getCurrentMake();
   QString getCurrentName();
+  QString getCurrentFullName();
 
   unsigned int getCurrentKeyset()
   {
@@ -84,6 +85,9 @@ public:
     QString label);
   void setupTabs(PIRTabBarName name);
 
+  bool selectNextKeyset();
+  bool selectPrevKeyset();
+
 signals:
   void buttonPressed(
     unsigned int keysetID,
