@@ -26,6 +26,7 @@ enum PIRMakeName{
   Daewoo_Make,
   Dell_Make,
   Denon_Make,
+  DeutscheTelekom_Make,
   DigitalStream_Make,
   Directv_Make,
   Dish_Make,
@@ -35,12 +36,14 @@ enum PIRMakeName{
   Ei_Make,
   Elgato_Make,
   Emerson_Make,
+  Emtec_Make,
   Epson_Make,
   Fortec_Make,
   Foxtel_Make,
   Gadmei_Make,
   Genius_Make,
   GoldStar_Make,
+  Goodmans_Make,
   Grundig_Make,
   Haier_Make,
   HarmanKardon_Make,
@@ -68,12 +71,15 @@ enum PIRMakeName{
   Mitsubishi_Make,
   Motorola_Make,
   NAD_Make,
+  Nikon_Make,
   Nokia_Make,
   Octagon_Make,
+  Olympus_Make,
   Onida_Make,
   Onkyo_Make,
   Orion_Make,
   Panasonic_Make,
+  Pentax_Make,
   Philco_Make,
   Philips_Make,
   Pinnacle_Make,
